[![Tests](https://github.com/jonathan-shemer/chenv/workflows/Tests/badge.svg)](https://github.com/jonathan-shemer/chenv/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/jonathan-shemer/chenv/branch/master/graph/badge.svg)](https://codecov.io/gh/jonathan-shemer/chenv)
[![PyPI](https://img.shields.io/pypi/v/chenv.svg)](https://pypi.org/project/chenv/)
[![Read the Docs](https://readthedocs.org/projects/chenv/badge/)](https://chenv.readthedocs.io/)

```
      _
  ___| |__   ___ _ ____   __
 / __| '_ \ / _ | '_ \ \ / /
| (__| | | |  __| | | \ V /
 \___|_| |_|\___|_| |_|\_/ . modern local environment management
```
